use crypto::ciphers::{
    aes_gcm::Aes256Gcm,
    traits::Aead,
};
use crypto::utils::rand;

const NONCE: [u8; 12] = [0xd0, 0xc3, 0x75, 0x56, 0x58, 0xc1, 0x7e, 0x5f, 0xd6, 0xcc, 0xb6, 0x76];

pub fn encrypt(key: &[u8; 32], plaintext: &[u8]) -> Vec<u8> {
	let mut result = vec![0; plaintext.len() + 16];
	let (cyphertext, tag) = result.split_at_mut(plaintext.len());
	Aes256Gcm::try_encrypt(
		key,
		&NONCE,
		&[],
		plaintext,
		cyphertext,
		tag).expect("Unexpected cryptography error");
	result
}

pub fn make_key() -> [u8; 32] {
	let mut result = [0; 32];
	rand::fill(&mut result).expect("Unexpected error generating random data");
	result
}
